# Drizm Python Commons

<p align="center">
    <a href="https://badge.fury.io/py/drizm-commons">
        <img 
        src="https://badge.fury.io/py/drizm-commons.svg" 
        alt="PyPI version" height="18"
        >
    </a>
    <a href="https://github.com/psf/black">
        <img
        src="https://img.shields.io/badge/code%20style-black-000000.svg"
        alt="Code Style" height="18"
        >
    </a>
</p>

---
Documentation:  
https://commons.python.drizm.com/
---

This package contains shared code used by
the Drizm organizations development team.  

It is not intended for public usage,
but you may still download,
redistribute or modify it to your liking.

**Author:**  
[Ben "ThaRising" Koch](https://github.com/ThaRising)

**Maintainers:**  
[Dominik Lewandowski](https://github.com/dominik-lewandowski)

## Requirements

Python **^3.8.X** supported.

**Debian 9+** and **Ubuntu 18.04+** for Linux,
as well as **Windows 10 1909+**,
are tested and supported.

Other OS are still most likely supported,
but were not explicitly tested.
